from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EmergencyStopStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[EmergencyStopStatus]
    SUCCESS: _ClassVar[EmergencyStopStatus]
    ERROR: _ClassVar[EmergencyStopStatus]
UNSPECIFIED: EmergencyStopStatus
SUCCESS: EmergencyStopStatus
ERROR: EmergencyStopStatus

class EmergencyStopRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class EmergencyStopResponse(_message.Message):
    __slots__ = ("status_message", "status")
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status_message: str
    status: EmergencyStopStatus
    def __init__(self, status_message: _Optional[str] = ..., status: _Optional[_Union[EmergencyStopStatus, str]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/global_variable_symbol.proto')
_sym_db = _symbol_database.Default()
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
from .. import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&scripting/global_variable_symbol.proto\x12\x18ares.datamodel.scripting\x1a\x16ares_data_schema.proto\x1a\x11ares_struct.proto"\x94\x01\n\x14GlobalVariableSymbol\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12/\n\x06schema\x18\x03 \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12(\n\x05value\x18\x04 \x01(\x0b2\x19.ares.datamodel.AresValueb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.global_variable_symbol_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GLOBALVARIABLESYMBOL']._serialized_start = 112
    _globals['_GLOBALVARIABLESYMBOL']._serialized_end = 260


"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from ...analyzing import analysis_pb2 as analyzing_dot_analysis__pb2
from ...analyzing import analyzer_capabilities_pb2 as analyzing_dot_analyzer__capabilities__pb2
from ...analyzing.remote import ares_remote_analyzer_service_pb2 as analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2
from ...connection import connection_info_pb2 as connection_dot_connection__info__pb2
from ...connection import connection_state_pb2 as connection_dot_connection__state__pb2
from ...connection import connection_status_pb2 as connection_dot_connection__status__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in analyzing/remote/ares_remote_analyzer_service_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresRemoteAnalyzerServiceStub(object):
    """defines a contract for ares to use in order to talk to a remote analyzer
    designed to be similar to the internal ARES analyzer implementation
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Analyze = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/Analyze', request_serializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.AnalysisRequest.SerializeToString, response_deserializer=analyzing_dot_analysis__pb2.Analysis.FromString, _registered_method=True)
        self.GetAnalyzerCapabilities = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetAnalyzerCapabilities', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=analyzing_dot_analyzer__capabilities__pb2.AnalyzerCapabilities.FromString, _registered_method=True)
        self.ValidateInputs = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/ValidateInputs', request_serializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.ParameterValidationRequest.SerializeToString, response_deserializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.ParameterValidationResult.FromString, _registered_method=True)
        self.GetAnalysisParameters = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetAnalysisParameters', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.AnalysisParametersResponse.FromString, _registered_method=True)
        self.GetConnectionStatus = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetConnectionStatus', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=connection_dot_connection__status__pb2.ConnectionStatus.FromString, _registered_method=True)
        self.GetState = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetState', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=connection_dot_connection__state__pb2.StateResponse.FromString, _registered_method=True)
        self.GetInfo = channel.unary_unary('/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetInfo', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=connection_dot_connection__info__pb2.InfoResponse.FromString, _registered_method=True)

class AresRemoteAnalyzerServiceServicer(object):
    """defines a contract for ares to use in order to talk to a remote analyzer
    designed to be similar to the internal ARES analyzer implementation
    """

    def Analyze(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAnalyzerCapabilities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateInputs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAnalysisParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectionStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresRemoteAnalyzerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'Analyze': grpc.unary_unary_rpc_method_handler(servicer.Analyze, request_deserializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.AnalysisRequest.FromString, response_serializer=analyzing_dot_analysis__pb2.Analysis.SerializeToString), 'GetAnalyzerCapabilities': grpc.unary_unary_rpc_method_handler(servicer.GetAnalyzerCapabilities, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=analyzing_dot_analyzer__capabilities__pb2.AnalyzerCapabilities.SerializeToString), 'ValidateInputs': grpc.unary_unary_rpc_method_handler(servicer.ValidateInputs, request_deserializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.ParameterValidationRequest.FromString, response_serializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.ParameterValidationResult.SerializeToString), 'GetAnalysisParameters': grpc.unary_unary_rpc_method_handler(servicer.GetAnalysisParameters, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.AnalysisParametersResponse.SerializeToString), 'GetConnectionStatus': grpc.unary_unary_rpc_method_handler(servicer.GetConnectionStatus, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=connection_dot_connection__status__pb2.ConnectionStatus.SerializeToString), 'GetState': grpc.unary_unary_rpc_method_handler(servicer.GetState, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=connection_dot_connection__state__pb2.StateResponse.SerializeToString), 'GetInfo': grpc.unary_unary_rpc_method_handler(servicer.GetInfo, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=connection_dot_connection__info__pb2.InfoResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.datamodel.analyzing.remote.AresRemoteAnalyzerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.datamodel.analyzing.remote.AresRemoteAnalyzerService', rpc_method_handlers)

class AresRemoteAnalyzerService(object):
    """defines a contract for ares to use in order to talk to a remote analyzer
    designed to be similar to the internal ARES analyzer implementation
    """

    @staticmethod
    def Analyze(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/Analyze', analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.AnalysisRequest.SerializeToString, analyzing_dot_analysis__pb2.Analysis.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAnalyzerCapabilities(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetAnalyzerCapabilities', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, analyzing_dot_analyzer__capabilities__pb2.AnalyzerCapabilities.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ValidateInputs(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/ValidateInputs', analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.ParameterValidationRequest.SerializeToString, analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.ParameterValidationResult.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAnalysisParameters(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetAnalysisParameters', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, analyzing_dot_remote_dot_ares__remote__analyzer__service__pb2.AnalysisParametersResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetConnectionStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetConnectionStatus', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, connection_dot_connection__status__pb2.ConnectionStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetState', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, connection_dot_connection__state__pb2.StateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.analyzing.remote.AresRemoteAnalyzerService/GetInfo', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, connection_dot_connection__info__pb2.InfoResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


from ares_datamodel.ares_struct_pb2 import QuantityValue
from ares_datamodel.ares_quantity_type_pb2 import QuantityType
import pytest

from ares_datamodel.quantity_units import (
    from_pint_quantity,
    to_pint_quantity,
    to_pint_unit,
    from_pint_unit,
    infer_quantity_type,
    to_quantity_schema,
)
from ares_datamodel.quantity_validation import validate_quantity_type_match
from ares_datamodel.quantity_validation import validate_quantity_value

from pint import UnitRegistry


def test_to_pint_quantity_length():
    value = QuantityValue(scalar=250.0, unit="millimeter")

    q = to_pint_quantity(value)

    assert q.to("meter").magnitude == pytest.approx(0.25, rel=0, abs=1e-8)


def test_to_pint_quantity_electric_potential():
    value = QuantityValue(scalar=12.0, unit="volt")

    q = to_pint_quantity(value)

    assert q.to("volt").magnitude == pytest.approx(12.0, rel=0, abs=1e-8)


def test_to_pint_quantity_heat_flux():
    value = QuantityValue(scalar=500.0, unit="watt / meter ** 2")

    q = to_pint_quantity(value)

    assert q.to("watt / meter ** 2").magnitude == pytest.approx(500.0, rel=0, abs=1e-8)


def test_to_pint_quantity_rejects_missing_unit():
    value = QuantityValue(scalar=1.0, unit="")

    with pytest.raises(ValueError):
        to_pint_quantity(value)


def test_from_pint_quantity_length_to_mm():
    source = to_pint_quantity(QuantityValue(scalar=0.25, unit="meter"))

    converted = from_pint_quantity(source, unit="mm")

    assert converted.unit == "mm"
    assert converted.scalar == pytest.approx(250.0, rel=0, abs=1e-8)
    assert converted.type == QuantityType.LENGTH


def test_to_and_from_quantity_area():
    value = QuantityValue(scalar=200, unit="m^2")
    ureg = UnitRegistry()

    converted = to_pint_quantity(value)
    test = converted.to(ureg.kilometer ** 2)
    quant_val = from_pint_quantity(test)

    assert quant_val.unit == "km^2"
    assert quant_val.type == QuantityType.AREA


def test_to_and_from_quantity_acceleration():
    value = QuantityValue(scalar=9.81, unit="m/s^2")
    ureg = UnitRegistry()

    converted = to_pint_quantity(value)
    test = converted.to(ureg.kilometer / (ureg.second ** 2))
    quant_val = from_pint_quantity(test)

    assert quant_val.unit in ("km/s^2", "km/s\u00b2")
    assert quant_val.type == QuantityType.ACCELERATION


def test_validate_quantity_value_opt_in_type_match_passes():
    value = QuantityValue(scalar=1.0, unit="m/s^2")

    validate_quantity_value(value, quantity_type=QuantityType.ACCELERATION)


def test_validate_quantity_value_opt_in_type_match_rejects_mismatch():
    value = QuantityValue(scalar=1.0, unit="second")

    with pytest.raises(ValueError):
        validate_quantity_value(value, quantity_type=QuantityType.LENGTH)


def test_validate_quantity_type_match_helper():
    value = QuantityValue(scalar=5.0, unit="volt")

    validate_quantity_type_match(value, QuantityType.ELECTRIC_POTENTIAL)


def test_to_pint_unit():
    unit = to_pint_unit("meter / second^2")
    assert str(unit.dimensionality) == "[length] / [time] ** 2"


def test_from_pint_unit():
    ureg = UnitRegistry()
    unit = ureg.parse_units("kilogram * meter / second^2")
    unit_str = from_pint_unit(unit)
    assert unit_str == "kg*m/s^2"


def test_infer_quantity_type():
    assert infer_quantity_type("meter") == QuantityType.LENGTH
    assert infer_quantity_type("m/s^2") == QuantityType.ACCELERATION
    assert infer_quantity_type("degC") == QuantityType.TEMPERATURE
    assert infer_quantity_type("delta_degC") == QuantityType.TEMPERATURE_DELTA
    assert infer_quantity_type("unknown_unit") == QuantityType.QUANTITY_TYPE_UNSPECIFIED


def test_to_quantity_schema():
    schema = to_quantity_schema("mm", min_scalar_value=0.0, max_scalar_value=100.0)
    assert schema.quantity_type == QuantityType.LENGTH
    assert schema.bounds_unit == "mm"
    assert schema.min_scalar_value == 0.0
    assert schema.max_scalar_value == 100.0




"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_polling_settings.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$device/device_polling_settings.proto\x12\x15ares.datamodel.device"y\n\x15DevicePollingSettings\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x128\n\x0cpolling_type\x18\x02 \x01(\x0e2".ares.datamodel.device.PollingType\x12\x13\n\x0binterval_ms\x18\x03 \x01(\x12*4\n\x0bPollingType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08INTERVAL\x10\x01\x12\r\n\tON_CHANGE\x10\x02b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_polling_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_POLLINGTYPE']._serialized_start = 186
    _globals['_POLLINGTYPE']._serialized_end = 238
    _globals['_DEVICEPOLLINGSETTINGS']._serialized_start = 63
    _globals['_DEVICEPOLLINGSETTINGS']._serialized_end = 184


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_device_driver_service.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ares_device_driver_service.proto\x12\rares.services\x1a\x1bgoogle/protobuf/empty.proto"@\n\x12DriverListResponse\x12*\n\x07drivers\x18\x01 \x03(\x0b2\x19.ares.services.DriverInfo"_\n\nDriverInfo\x12\x11\n\tdriver_id\x18\x01 \x01(\t\x12\x14\n\x0cdisplay_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x17\n\x0ffile_size_bytes\x18\x04 \x01(\x03""\n\rDriverRequest\x12\x11\n\tdriver_id\x18\x01 \x01(\t",\n\tFileChunk\x12\x0f\n\x07content\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x032\xb7\x01\n\x17AresDeviceDriverService\x12P\n\x13GetAvailableDrivers\x12\x16.google.protobuf.Empty\x1a!.ares.services.DriverListResponse\x12J\n\x0eDownloadDriver\x12\x1c.ares.services.DriverRequest\x1a\x18.ares.services.FileChunk0\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_device_driver_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DRIVERLISTRESPONSE']._serialized_start = 80
    _globals['_DRIVERLISTRESPONSE']._serialized_end = 144
    _globals['_DRIVERINFO']._serialized_start = 146
    _globals['_DRIVERINFO']._serialized_end = 241
    _globals['_DRIVERREQUEST']._serialized_start = 243
    _globals['_DRIVERREQUEST']._serialized_end = 277
    _globals['_FILECHUNK']._serialized_start = 279
    _globals['_FILECHUNK']._serialized_end = 323
    _globals['_ARESDEVICEDRIVERSERVICE']._serialized_start = 326
    _globals['_ARESDEVICEDRIVERSERVICE']._serialized_end = 509


from analyzing import analyzer_info_pb2 as _analyzer_info_pb2
from connection import connection_state_pb2 as _connection_state_pb2
from analyzing import analyzer_settings_pb2 as _analyzer_settings_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetAllAnalyzersResponse(_message.Message):
    __slots__ = ("analyzers",)
    ANALYZERS_FIELD_NUMBER: _ClassVar[int]
    analyzers: _containers.RepeatedCompositeFieldContainer[_analyzer_info_pb2.AnalyzerInfo]
    def __init__(self, analyzers: _Optional[_Iterable[_Union[_analyzer_info_pb2.AnalyzerInfo, _Mapping]]] = ...) -> None: ...

class AddRemoteAnalyzerRequest(_message.Message):
    __slots__ = ("name", "url")
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    name: str
    url: str
    def __init__(self, name: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class AddRemoteAnalyzerResponse(_message.Message):
    __slots__ = ("analyzer_id", "success", "error_message")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    success: bool
    error_message: str
    def __init__(self, analyzer_id: _Optional[str] = ..., success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class UpdateRemoteAnalyzerRequest(_message.Message):
    __slots__ = ("analyzer_id", "name", "url")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    name: str
    url: str
    def __init__(self, analyzer_id: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class UpdateRemoteAnalyzerResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class RemoveRemoteAnalyzerRequest(_message.Message):
    __slots__ = ("analyzer_id", "success", "error_message")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    success: bool
    error_message: str
    def __init__(self, analyzer_id: _Optional[str] = ..., success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class AnalyzerInfoRequest(_message.Message):
    __slots__ = ("analyzer_id",)
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    def __init__(self, analyzer_id: _Optional[str] = ...) -> None: ...

class AnalyzerInfoResponse(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _analyzer_info_pb2.AnalyzerInfo
    def __init__(self, info: _Optional[_Union[_analyzer_info_pb2.AnalyzerInfo, _Mapping]] = ...) -> None: ...

class AnalyzerSettingsRequest(_message.Message):
    __slots__ = ("analyzer_id",)
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    def __init__(self, analyzer_id: _Optional[str] = ...) -> None: ...



from __future__ import annotations

from ares_datamodel.ares_quantity_type_pb2 import QuantityType
from ares_datamodel.ares_struct_pb2 import QuantityValue
from pint import UnitRegistry

_UNIT_REGISTRY = UnitRegistry()

QUANTITY_TYPE_TO_CANONICAL_UNIT: dict[QuantityType, str] = {
    QuantityType.LENGTH: "meter",
    QuantityType.ACCELERATION: "meter/second**2",
    QuantityType.AREA: "meter**2",
    QuantityType.VOLUME: "meter**3",
    QuantityType.DURATION: "second",
    QuantityType.SPEED: "meter/second",
    QuantityType.FREQUENCY: "hertz",
    QuantityType.MASS: "kilogram",
    QuantityType.AMOUNT_OF_SUBSTANCE: "mole",
    QuantityType.MOLAR_MASS: "kilogram/mole",
    QuantityType.TEMPERATURE: "kelvin",
    QuantityType.TEMPERATURE_DELTA: "delta_degC",
    QuantityType.PRESSURE: "pascal",
    QuantityType.MOLARITY: "mole/liter",
    QuantityType.MASS_CONCENTRATION: "kilogram/meter**3",
    QuantityType.VOLUME_CONCENTRATION: "dimensionless",
    QuantityType.MASS_FRACTION: "dimensionless",
    QuantityType.DENSITY: "kilogram/meter**3",
    QuantityType.DYNAMIC_VISCOSITY: "pascal*second",
    QuantityType.KINEMATIC_VISCOSITY: "meter**2/second",
    QuantityType.VOLUME_FLOW: "meter**3/second",
    QuantityType.MASS_FLOW: "kilogram/second",
    QuantityType.MASS_FLUX: "kilogram/(meter**2*second)",
    QuantityType.ROTATIONAL_ACCELERATION: "radian/second**2",
    QuantityType.ROTATIONAL_SPEED: "radian/second",
    QuantityType.ENERGY: "joule",
    QuantityType.POWER: "watt",
    QuantityType.HEAT_FLUX: "watt/meter**2",
    QuantityType.SPECIFIC_ENERGY: "joule/kilogram",
    QuantityType.THERMAL_CONDUCTIVITY: "watt/(meter*kelvin)",
    QuantityType.FORCE: "newton",
    QuantityType.FORCE_PER_LENGTH: "newton/meter",
    QuantityType.RATIO: "dimensionless",
    QuantityType.IRRADIANCE: "watt/meter**2",
    QuantityType.ILLUMINANCE: "lux",
    QuantityType.TEMPERATURE_GRADIENT: "kelvin/meter",
    QuantityType.ELECTRIC_POTENTIAL: "volt",
    QuantityType.ELECTRIC_CURRENT: "ampere",
    QuantityType.ELECTRIC_RESISTANCE: "ohm",
    QuantityType.ELECTRIC_CONDUCTIVITY: "siemens/meter",
    QuantityType.ELECTRIC_CONDUCTANCE: "siemens",
    QuantityType.RATIO_CHANGE_RATE: "1/second",
    QuantityType.RELATIVE_HUMIDITY: "dimensionless",
}


def validate_quantity_value(
    quantity_value: QuantityValue,
    quantity_type: QuantityType | None = None,
    registry: UnitRegistry | None = None,
) -> None:
    ureg = registry or _UNIT_REGISTRY

    if not quantity_value.unit or not quantity_value.unit.strip():
        raise ValueError("Quantity unit must be specified.")

    source = float(quantity_value.scalar) * ureg.parse_units(quantity_value.unit)

    if quantity_type is None:
        return

    if quantity_type == QuantityType.QUANTITY_TYPE_UNSPECIFIED:
        raise ValueError("Quantity type must be specified.")

    expected_unit = QUANTITY_TYPE_TO_CANONICAL_UNIT.get(quantity_type)
    if expected_unit is None:
        quantity_type_name = QuantityType.Name(quantity_type)
        raise ValueError(f"No canonical Pint unit mapping for quantity type '{quantity_type_name}'.")

    target = 1.0 * ureg.parse_units(expected_unit)
    if source.dimensionality != target.dimensionality:
        quantity_type_name = QuantityType.Name(quantity_type)
        raise ValueError(
            f"Unit '{quantity_value.unit}' is incompatible with quantity type "
            f"'{quantity_type_name}' (expected dimensionality of '{expected_unit}')."
        )


def validate_quantity_type_match(
    quantity_value: QuantityValue,
    quantity_type: QuantityType,
    registry: UnitRegistry | None = None,
) -> None:
    validate_quantity_value(quantity_value, registry=registry, quantity_type=quantity_type)



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/completion.proto')
_sym_db = _symbol_database.Default()
from ..scripting import script_symbol_metadata_pb2 as scripting_dot_script__symbol__metadata__pb2
from ..scripting import symbol_kind_pb2 as scripting_dot_symbol__kind__pb2
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/completion.proto\x12\x18ares.datamodel.scripting\x1a&scripting/script_symbol_metadata.proto\x1a\x1bscripting/symbol_kind.proto\x1a\x16ares_data_schema.proto"\xe8\x03\n\x0eCompletionItem\x12\r\n\x05label\x18\x01 \x01(\t\x12\x13\n\x0binsert_text\x18\x02 \x01(\t\x12F\n\x12insert_text_format\x18\x03 \x01(\x0e2*.ares.datamodel.scripting.InsertTextFormat\x12\x11\n\tsort_text\x18\x04 \x01(\t\x12@\n\x08metadata\x18\x05 \x01(\x0b2..ares.datamodel.scripting.ScriptSymbolMetadata\x12\x0e\n\x06detail\x18\x06 \x01(\t\x12\x15\n\rdocumentation\x18\x07 \x01(\t\x122\n\x04kind\x18\x08 \x01(\x0e2$.ares.datamodel.scripting.SymbolKind\x12\x19\n\x11parent_identifier\x18\t \x01(\t\x126\n\x0cinput_schema\x18\n \x01(\x0b2 .ares.datamodel.AresStructSchema\x126\n\routput_schema\x18\x0b \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12/\n\x06schema\x18\x0c \x01(\x0b2\x1f.ares.datamodel.AresValueSchema*U\n\x10InsertTextFormat\x12!\n\x1dINSERT_TEXT_FORMAT_PLAIN_TEXT\x10\x00\x12\x1e\n\x1aINSERT_TEXT_FORMAT_SNIPPET\x10\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.completion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_INSERTTEXTFORMAT']._serialized_start = 640
    _globals['_INSERTTEXTFORMAT']._serialized_end = 725
    _globals['_COMPLETIONITEM']._serialized_start = 150
    _globals['_COMPLETIONITEM']._serialized_end = 638


from planning import planner_service_info_pb2 as _planner_service_info_pb2
from planning import planner_settings_pb2 as _planner_settings_pb2
from planning import manual_planner_pb2 as _manual_planner_pb2
from connection import connection_state_pb2 as _connection_state_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlannerInfoRequest(_message.Message):
    __slots__ = ("planner_id",)
    PLANNER_ID_FIELD_NUMBER: _ClassVar[int]
    planner_id: str
    def __init__(self, planner_id: _Optional[str] = ...) -> None: ...

class PlannerInfoResponse(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _planner_service_info_pb2.PlannerServiceInfo
    def __init__(self, info: _Optional[_Union[_planner_service_info_pb2.PlannerServiceInfo, _Mapping]] = ...) -> None: ...

class PlannerSettingsRequest(_message.Message):
    __slots__ = ("planner_id",)
    PLANNER_ID_FIELD_NUMBER: _ClassVar[int]
    planner_id: str
    def __init__(self, planner_id: _Optional[str] = ...) -> None: ...

class GetAllPlannersResponse(_message.Message):
    __slots__ = ("planners",)
    PLANNERS_FIELD_NUMBER: _ClassVar[int]
    planners: _containers.RepeatedCompositeFieldContainer[_planner_service_info_pb2.PlannerServiceInfo]
    def __init__(self, planners: _Optional[_Iterable[_Union[_planner_service_info_pb2.PlannerServiceInfo, _Mapping]]] = ...) -> None: ...

class AddPlannerRequest(_message.Message):
    __slots__ = ("name", "address")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    name: str
    address: str
    def __init__(self, name: _Optional[str] = ..., address: _Optional[str] = ...) -> None: ...

class AddPlannerResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class UpdatePlannerRequest(_message.Message):
    __slots__ = ("planner_id", "name", "url")
    PLANNER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    planner_id: str
    name: str
    url: str
    def __init__(self, planner_id: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class UpdatePlannerResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class RemovePlannerRequest(_message.Message):
    __slots__ = ("planner_id",)
    PLANNER_ID_FIELD_NUMBER: _ClassVar[int]
    planner_id: str
    def __init__(self, planner_id: _Optional[str] = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from planning import plan_pb2 as _plan_pb2
from planning import planner_service_capabilities_pb2 as _planner_service_capabilities_pb2
from connection import connection_state_pb2 as _connection_state_pb2
from connection import connection_status_pb2 as _connection_status_pb2
from connection import connection_info_pb2 as _connection_info_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_logging_settings.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$device/device_logging_settings.proto\x12\x15ares.datamodel.device"\xbe\x02\n\x15DeviceLoggingSettings\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12N\n\x0clogging_type\x18\x02 \x01(\x0e28.ares.datamodel.device.DeviceLoggingSettings.LoggingType\x12\x13\n\x0binterval_ms\x18\x03 \x01(\x12\x12H\n\x06deltas\x18\x04 \x03(\x0b28.ares.datamodel.device.DeviceLoggingSettings.DeltasEntry\x1a-\n\x0bDeltasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x028\x01"4\n\x0bLoggingType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08INTERVAL\x10\x01\x12\r\n\tON_CHANGE\x10\x02b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_logging_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DEVICELOGGINGSETTINGS_DELTASENTRY']._loaded_options = None
    _globals['_DEVICELOGGINGSETTINGS_DELTASENTRY']._serialized_options = b'8\x01'
    _globals['_DEVICELOGGINGSETTINGS']._serialized_start = 64
    _globals['_DEVICELOGGINGSETTINGS']._serialized_end = 382
    _globals['_DEVICELOGGINGSETTINGS_DELTASENTRY']._serialized_start = 283
    _globals['_DEVICELOGGINGSETTINGS_DELTASENTRY']._serialized_end = 328
    _globals['_DEVICELOGGINGSETTINGS_LOGGINGTYPE']._serialized_start = 330
    _globals['_DEVICELOGGINGSETTINGS_LOGGINGTYPE']._serialized_end = 382


from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InternalVariableType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAR_UNSPECIFIED: _ClassVar[InternalVariableType]
    CURRENT_EXPERIMENT_NUMBER: _ClassVar[InternalVariableType]
    CURRENT_CAMPAIGN_ID: _ClassVar[InternalVariableType]
    CURRENT_CAMPAIGN_NAME: _ClassVar[InternalVariableType]
VAR_UNSPECIFIED: InternalVariableType
CURRENT_EXPERIMENT_NUMBER: InternalVariableType
CURRENT_CAMPAIGN_ID: InternalVariableType
CURRENT_CAMPAIGN_NAME: InternalVariableType

class InternalVariableAllocation(_message.Message):
    __slots__ = ("unique_id", "internal_variable_type", "value")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_VARIABLE_TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    internal_variable_type: InternalVariableType
    value: str
    def __init__(self, unique_id: _Optional[str] = ..., internal_variable_type: _Optional[_Union[InternalVariableType, str]] = ..., value: _Optional[str] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/script_summary_step.proto')
_sym_db = _symbol_database.Default()
from ..scripting import function_invocation_kind_pb2 as scripting_dot_function__invocation__kind__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#scripting/script_summary_step.proto\x12\x18ares.datamodel.scripting\x1a(scripting/function_invocation_kind.proto"\xc7\x01\n\x18ScriptFunctionInvocation\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x13\n\x0bfunction_id\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x0c\n\x04line\x18\x05 \x01(\x05\x12\x0e\n\x06column\x18\x06 \x01(\x05\x12>\n\x04kind\x18\x07 \x01(\x0e20.ares.datamodel.scripting.FunctionInvocationKindb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.script_summary_step_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTFUNCTIONINVOCATION']._serialized_start = 108
    _globals['_SCRIPTFUNCTIONINVOCATION']._serialized_end = 307


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'analyzing/remote/ares_remote_analyzer_service.proto')
_sym_db = _symbol_database.Default()
from ...analyzing import analysis_pb2 as analyzing_dot_analysis__pb2
from ... import ares_struct_pb2 as ares__struct__pb2
from ... import request_metadata_pb2 as request__metadata__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from ...analyzing import analyzer_capabilities_pb2 as analyzing_dot_analyzer__capabilities__pb2
from ... import ares_data_schema_pb2 as ares__data__schema__pb2
from ...connection import connection_status_pb2 as connection_dot_connection__status__pb2
from ...connection import connection_info_pb2 as connection_dot_connection__info__pb2
from ...connection import connection_state_pb2 as connection_dot_connection__state__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3analyzing/remote/ares_remote_analyzer_service.proto\x12\x1fares.datamodel.analyzing.remote\x1a\x18analyzing/analysis.proto\x1a\x11ares_struct.proto\x1a\x16request_metadata.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a%analyzing/analyzer_capabilities.proto\x1a\x16ares_data_schema.proto\x1a"connection/connection_status.proto\x1a connection/connection_info.proto\x1a!connection/connection_state.proto"T\n\x1aParameterValidationRequest\x126\n\x0cinput_schema\x18\x01 \x01(\x0b2 .ares.datamodel.AresStructSchema">\n\x19ParameterValidationResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08messages\x18\x02 \x03(\t"\x9e\x01\n\x0fAnalysisRequest\x12*\n\x06inputs\x18\x01 \x01(\x0b2\x1a.ares.datamodel.AresStruct\x12,\n\x08settings\x18\x02 \x01(\x0b2\x1a.ares.datamodel.AresStruct\x121\n\x08metadata\x18\x03 \x01(\x0b2\x1f.ares.datamodel.RequestMetadata"X\n\x1aAnalysisParametersResponse\x12:\n\x10parameter_schema\x18\x01 \x01(\x0b2 .ares.datamodel.AresStructSchema2\xcf\x05\n\x19AresRemoteAnalyzerService\x12_\n\x07Analyze\x120.ares.datamodel.analyzing.remote.AnalysisRequest\x1a".ares.datamodel.analyzing.Analysis\x12a\n\x17GetAnalyzerCapabilities\x12\x16.google.protobuf.Empty\x1a..ares.datamodel.analyzing.AnalyzerCapabilities\x12\x89\x01\n\x0eValidateInputs\x12;.ares.datamodel.analyzing.remote.ParameterValidationRequest\x1a:.ares.datamodel.analyzing.remote.ParameterValidationResult\x12l\n\x15GetAnalysisParameters\x12\x16.google.protobuf.Empty\x1a;.ares.datamodel.analyzing.remote.AnalysisParametersResponse\x12Z\n\x13GetConnectionStatus\x12\x16.google.protobuf.Empty\x1a+.ares.datamodel.connection.ConnectionStatus\x12L\n\x08GetState\x12\x16.google.protobuf.Empty\x1a(.ares.datamodel.connection.StateResponse\x12J\n\x07GetInfo\x12\x16.google.protobuf.Empty\x1a\'.ares.datamodel.connection.InfoResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analyzing.remote.ares_remote_analyzer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PARAMETERVALIDATIONREQUEST']._serialized_start = 354
    _globals['_PARAMETERVALIDATIONREQUEST']._serialized_end = 438
    _globals['_PARAMETERVALIDATIONRESULT']._serialized_start = 440
    _globals['_PARAMETERVALIDATIONRESULT']._serialized_end = 502
    _globals['_ANALYSISREQUEST']._serialized_start = 505
    _globals['_ANALYSISREQUEST']._serialized_end = 663
    _globals['_ANALYSISPARAMETERSRESPONSE']._serialized_start = 665
    _globals['_ANALYSISPARAMETERSRESPONSE']._serialized_end = 753
    _globals['_ARESREMOTEANALYZERSERVICE']._serialized_start = 756
    _globals['_ARESREMOTEANALYZERSERVICE']._serialized_end = 1475


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'planning/manual_planner.proto')
_sym_db = _symbol_database.Default()
from .. import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dplanning/manual_planner.proto\x12\x17ares.datamodel.planning\x1a\x11ares_struct.proto"\xba\x01\n\x11ManualPlannerSeed\x12M\n\x0eplanner_values\x18\x01 \x01(\x0b23.ares.datamodel.planning.ManualPlannerSetCollectionH\x00\x12E\n\nfile_lines\x18\x02 \x01(\x0b2/.ares.datamodel.planning.ManualPlannerFileLinesH\x00B\x0f\n\rplanner_stuff"]\n\x10ManualPlannerSet\x12I\n\x10parameter_values\x18\x01 \x03(\x0b2/.ares.datamodel.planning.ParameterNameValuePair"P\n\x16ParameterNameValuePair\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue"0\n\x16ManualPlannerFileLines\x12\x16\n\x0eplanner_values\x18\x01 \x03(\t"_\n\x1aManualPlannerSetCollection\x12A\n\x0eplanned_values\x18\x01 \x03(\x0b2).ares.datamodel.planning.ManualPlannerSetb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'planning.manual_planner_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_MANUALPLANNERSEED']._serialized_start = 78
    _globals['_MANUALPLANNERSEED']._serialized_end = 264
    _globals['_MANUALPLANNERSET']._serialized_start = 266
    _globals['_MANUALPLANNERSET']._serialized_end = 359
    _globals['_PARAMETERNAMEVALUEPAIR']._serialized_start = 361
    _globals['_PARAMETERNAMEVALUEPAIR']._serialized_end = 441
    _globals['_MANUALPLANNERFILELINES']._serialized_start = 443
    _globals['_MANUALPLANNERFILELINES']._serialized_end = 491
    _globals['_MANUALPLANNERSETCOLLECTION']._serialized_start = 493
    _globals['_MANUALPLANNERSETCOLLECTION']._serialized_end = 588


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'templates/campaign_template.proto')
_sym_db = _symbol_database.Default()
from ..templates import experiment_template_pb2 as templates_dot_experiment__template__pb2
from ..templates import parameter_metadata_pb2 as templates_dot_parameter__metadata__pb2
from ..planning import planner_allocation_pb2 as planning_dot_planner__allocation__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!templates/campaign_template.proto\x12\x18ares.datamodel.templates\x1a#templates/experiment_template.proto\x1a"templates/parameter_metadata.proto\x1a!planning/planner_allocation.proto"\xb6\x03\n\x10CampaignTemplate\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12F\n\x10startup_template\x18\x02 \x01(\x0b2,.ares.datamodel.templates.ExperimentTemplate\x12I\n\x13experiment_template\x18\x03 \x01(\x0b2,.ares.datamodel.templates.ExperimentTemplate\x12G\n\x11closeout_template\x18\x04 \x01(\x0b2,.ares.datamodel.templates.ExperimentTemplate\x12\x0c\n\x04name\x18\x05 \x01(\t\x12I\n\x14plannable_parameters\x18\x06 \x03(\x0b2+.ares.datamodel.templates.ParameterMetadata\x12G\n\x13planner_allocations\x18\x07 \x03(\x0b2*.ares.datamodel.planning.PlannerAllocationB\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templates.campaign_template_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CAMPAIGNTEMPLATE']._serialized_start = 172
    _globals['_CAMPAIGNTEMPLATE']._serialized_end = 610


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'execution_status_messages.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fexecution_status_messages.proto\x12\x0eares.datamodel"\x9b\x02\n\x17CampaignExecutionStatus\x12\x13\n\x0bcampaign_id\x18\x01 \x01(\t\x12-\n\x05state\x18\x02 \x01(\x0e2\x1e.ares.datamodel.ExecutionState\x12P\n\x1dexperiment_execution_statuses\x18\x03 \x03(\x0b2).ares.datamodel.ExperimentExecutionStatus\x125\n\x0eanalysis_state\x18\x04 \x01(\x0e2\x1d.ares.datamodel.AnalysisState\x123\n\rplanner_state\x18\x05 \x01(\x0e2\x1c.ares.datamodel.PlannerState"\xc8\x01\n\x16CampaignExecutionState\x12\x13\n\x0bcampaign_id\x18\x01 \x01(\t\x12-\n\x05state\x18\x02 \x01(\x0e2\x1e.ares.datamodel.ExecutionState\x125\n\x0eanalysis_state\x18\x03 \x01(\x0e2\x1d.ares.datamodel.AnalysisState\x123\n\rplanner_state\x18\x04 \x01(\x0e2\x1c.ares.datamodel.PlannerState"x\n\x19ExperimentExecutionStatus\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12D\n\x17step_execution_statuses\x18\x02 \x03(\x0b2#.ares.datamodel.StepExecutionStatus"u\n\x15CampaignStartupStatus\x12\x13\n\x0bcampaign_id\x18\x01 \x01(\t\x12G\n\x1astartup_execution_statuses\x18\x02 \x03(\x0b2#.ares.datamodel.StepExecutionStatus"w\n\x16CampaignCloseoutStatus\x12\x13\n\x0bcampaign_id\x18\x01 \x01(\t\x12H\n\x1bcloseout_execution_statuses\x18\x02 \x03(\x0b2#.ares.datamodel.StepExecutionStatus"\x85\x01\n\x13StepExecutionStatus\x12\x0f\n\x07step_id\x18\x01 \x01(\t\x12\x11\n\tstep_name\x18\x02 \x01(\t\x12J\n\x1acommand_execution_statuses\x18\x03 \x03(\x0b2&.ares.datamodel.CommandExecutionStatus"\x86\x01\n\x16CommandExecutionStatus\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12\x14\n\x0ccommand_name\x18\x02 \x01(\t\x12\x13\n\x0bdevice_name\x18\x03 \x01(\t\x12-\n\x05state\x18\x04 \x01(\x0e2\x1e.ares.datamodel.ExecutionState*s\n\x0eExecutionState\x12\r\n\tUNDEFINED\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x0b\n\x07WAITING\x10\x02\x12\x11\n\rAWAITING_USER\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\n\n\x06PAUSED\x10\x05\x12\n\n\x06FAILED\x10\x06*\x87\x01\n\rAnalysisState\x12\x18\n\x14NO_ANALYSIS_REQUIRED\x10\x00\x12\x17\n\x13ANALYSIS_INCOMPLETE\x10\x01\x12\x18\n\x14ANALYSIS_IN_PROGRESS\x10\x02\x12\x15\n\x11ANALYSIS_COMPLETE\x10\x03\x12\x12\n\x0eANALYSIS_ERROR\x10\x04*\x86\x01\n\x0cPlannerState\x12\x18\n\x14NO_PLANNING_REQUIRED\x10\x00\x12\x17\n\x13PLANNING_INCOMPLETE\x10\x01\x12\x18\n\x14PLANNING_IN_PROGRESS\x10\x02\x12\x15\n\x11PLANNING_COMPLETE\x10\x03\x12\x12\n\x0ePLANNING_ERROR\x10\x04b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'execution_status_messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_EXECUTIONSTATE']._serialized_start = 1175
    _globals['_EXECUTIONSTATE']._serialized_end = 1290
    _globals['_ANALYSISSTATE']._serialized_start = 1293
    _globals['_ANALYSISSTATE']._serialized_end = 1428
    _globals['_PLANNERSTATE']._serialized_start = 1431
    _globals['_PLANNERSTATE']._serialized_end = 1565
    _globals['_CAMPAIGNEXECUTIONSTATUS']._serialized_start = 52
    _globals['_CAMPAIGNEXECUTIONSTATUS']._serialized_end = 335
    _globals['_CAMPAIGNEXECUTIONSTATE']._serialized_start = 338
    _globals['_CAMPAIGNEXECUTIONSTATE']._serialized_end = 538
    _globals['_EXPERIMENTEXECUTIONSTATUS']._serialized_start = 540
    _globals['_EXPERIMENTEXECUTIONSTATUS']._serialized_end = 660
    _globals['_CAMPAIGNSTARTUPSTATUS']._serialized_start = 662
    _globals['_CAMPAIGNSTARTUPSTATUS']._serialized_end = 779
    _globals['_CAMPAIGNCLOSEOUTSTATUS']._serialized_start = 781
    _globals['_CAMPAIGNCLOSEOUTSTATUS']._serialized_end = 900
    _globals['_STEPEXECUTIONSTATUS']._serialized_start = 903
    _globals['_STEPEXECUTIONSTATUS']._serialized_end = 1036
    _globals['_COMMANDEXECUTIONSTATUS']._serialized_start = 1039
    _globals['_COMMANDEXECUTIONSTATUS']._serialized_end = 1173


import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceStateRequestFilter(_message.Message):
    __slots__ = ("start", "end", "completed_experiment_id", "completed_campaign_id", "interval", "device_ids")
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_EXPERIMENT_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    DEVICE_IDS_FIELD_NUMBER: _ClassVar[int]
    start: _timestamp_pb2.Timestamp
    end: _timestamp_pb2.Timestamp
    completed_experiment_id: _wrappers_pb2.StringValue
    completed_campaign_id: _wrappers_pb2.StringValue
    interval: _duration_pb2.Duration
    device_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., completed_experiment_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., completed_campaign_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., interval: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., device_ids: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from templates import command_metadata_pb2 as _command_metadata_pb2
from templates import command_template_pb2 as _command_template_pb2
from device import device_execution_result_pb2 as _device_execution_result_pb2
from device import remote_device_config_pb2 as _remote_device_config_pb2
from device import device_status_pb2 as _device_status_pb2
from device import device_info_pb2 as _device_info_pb2
from device import device_config_pb2 as _device_config_pb2
from device import device_settings_pb2 as _device_settings_pb2
from device import device_polling_settings_pb2 as _device_polling_settings_pb2
from device import device_description_pb2 as _device_description_pb2
import ares_struct_pb2 as _ares_struct_pb2
import ares_data_schema_pb2 as _ares_data_schema_pb2
from device import device_logging_settings_pb2 as _device_logging_settings_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListAresDevicesResponse(_message.Message):
    __slots__ = ("ares_devices",)
    ARES_DEVICES_FIELD_NUMBER: _ClassVar[int]
    ares_devices: _containers.RepeatedCompositeFieldContainer[_device_info_pb2.DeviceInfo]
    def __init__(self, ares_devices: _Optional[_Iterable[_Union[_device_info_pb2.DeviceInfo, _Mapping]]] = ...) -> None: ...

class ListAresRemoteDevicesResponse(_message.Message):
    __slots__ = ("devices",)
    DEVICES_FIELD_NUMBER: _ClassVar[int]
    devices: _containers.RepeatedCompositeFieldContainer[_device_info_pb2.DeviceInfo]
    def __init__(self, devices: _Optional[_Iterable[_Union[_device_info_pb2.DeviceInfo, _Mapping]]] = ...) -> None: ...

class ListServerSerialPortsResponse(_message.Message):
    __slots__ = ("serial_ports",)
    SERIAL_PORTS_FIELD_NUMBER: _ClassVar[int]
    serial_ports: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, serial_ports: _Optional[_Iterable[str]] = ...) -> None: ...

class CommandMetadatasRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class CommandMetadatasResponse(_message.Message):
    __slots__ = ("metadatas",)
    METADATAS_FIELD_NUMBER: _ClassVar[int]
    metadatas: _containers.RepeatedCompositeFieldContainer[_command_metadata_pb2.CommandMetadata]
    def __init__(self, metadatas: _Optional[_Iterable[_Union[_command_metadata_pb2.CommandMetadata, _Mapping]]] = ...) -> None: ...

class DeviceStatusRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceStateStreamRequest(_message.Message):
    __slots__ = ("device_id", "polling_settings")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    POLLING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    polling_settings: _device_polling_settings_pb2.DevicePollingSettings
    def __init__(self, device_id: _Optional[str] = ..., polling_settings: _Optional[_Union[_device_polling_settings_pb2.DevicePollingSettings, _Mapping]] = ...) -> None: ...

class DeviceStateRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceStateResponse(_message.Message):
    __slots__ = ("state",)
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: _ares_struct_pb2.AresStruct
    def __init__(self, state: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...

class DeviceStateSchemaRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceStateSchemaResponse(_message.Message):
    __slots__ = ("schema",)
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    schema: _ares_data_schema_pb2.AresStructSchema
    def __init__(self, schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ...) -> None: ...

class DeviceLoggerSettingsRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceLoggersResponse(_message.Message):
    __slots__ = ("loggers",)
    LOGGERS_FIELD_NUMBER: _ClassVar[int]
    loggers: _containers.RepeatedCompositeFieldContainer[_device_logging_settings_pb2.DeviceLoggingSettings]
    def __init__(self, loggers: _Optional[_Iterable[_Union[_device_logging_settings_pb2.DeviceLoggingSettings, _Mapping]]] = ...) -> None: ...

class DeviceInfoRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceSettingsRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceActivateRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class DeviceConfigRequest(_message.Message):
    __slots__ = ("device_type",)
    DEVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    device_type: str
    def __init__(self, device_type: _Optional[str] = ...) -> None: ...

class DeviceConfigResponse(_message.Message):
    __slots__ = ("configs",)
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[_device_config_pb2.DeviceConfig]
    def __init__(self, configs: _Optional[_Iterable[_Union[_device_config_pb2.DeviceConfig, _Mapping]]] = ...) -> None: ...

class RemoteDeviceConfigResponse(_message.Message):
    __slots__ = ("configs",)
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[_remote_device_config_pb2.RemoteDeviceConfig]
    def __init__(self, configs: _Optional[_Iterable[_Union[_remote_device_config_pb2.RemoteDeviceConfig, _Mapping]]] = ...) -> None: ...

class AddRemoteDeviceRequest(_message.Message):
    __slots__ = ("name", "url")
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    name: str
    url: str
    def __init__(self, name: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class AddRemoteDeviceResponse(_message.Message):
    __slots__ = ("device_id", "success", "error_message")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    success: bool
    error_message: str
    def __init__(self, device_id: _Optional[str] = ..., success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class UpdateRemoteDeviceRequest(_message.Message):
    __slots__ = ("device_id", "name", "url")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    name: str
    url: str
    def __init__(self, device_id: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class UpdateRemoteDeviceResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class RemoveRemoteDeviceRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class RemoveRemoteDeviceResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class AddDeviceRequest(_message.Message):
    __slots__ = ("device_name", "driver_name", "device_config")
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    DRIVER_NAME_FIELD_NUMBER: _ClassVar[int]
    DEVICE_CONFIG_FIELD_NUMBER: _ClassVar[int]
    device_name: str
    driver_name: str
    device_config: _device_config_pb2.DeviceConfig
    def __init__(self, device_name: _Optional[str] = ..., driver_name: _Optional[str] = ..., device_config: _Optional[_Union[_device_config_pb2.DeviceConfig, _Mapping]] = ...) -> None: ...

class AddDeviceResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class AvailableDeviceDriversResponse(_message.Message):
    __slots__ = ("device_drivers",)
    DEVICE_DRIVERS_FIELD_NUMBER: _ClassVar[int]
    device_drivers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, device_drivers: _Optional[_Iterable[str]] = ...) -> None: ...

class GetDeviceConfigRequest(_message.Message):
    __slots__ = ("driver_name", "driver_id")
    DRIVER_NAME_FIELD_NUMBER: _ClassVar[int]
    DRIVER_ID_FIELD_NUMBER: _ClassVar[int]
    driver_name: str
    driver_id: str
    def __init__(self, driver_name: _Optional[str] = ..., driver_id: _Optional[str] = ...) -> None: ...

class AvailableDevicesResponse(_message.Message):
    __slots__ = ("devices",)
    DEVICES_FIELD_NUMBER: _ClassVar[int]
    devices: _containers.RepeatedCompositeFieldContainer[_device_description_pb2.AresDeviceDescription]
    def __init__(self, devices: _Optional[_Iterable[_Union[_device_description_pb2.AresDeviceDescription, _Mapping]]] = ...) -> None: ...

class UpdateDeviceRequest(_message.Message):
    __slots__ = ("device_id", "updated_config")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_CONFIG_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    updated_config: _device_config_pb2.DeviceConfig
    def __init__(self, device_id: _Optional[str] = ..., updated_config: _Optional[_Union[_device_config_pb2.DeviceConfig, _Mapping]] = ...) -> None: ...

class UpdateDeviceResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class RemoveDeviceRequest(_message.Message):
    __slots__ = ("device_id",)
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    def __init__(self, device_id: _Optional[str] = ...) -> None: ...

class RemoveDeviceResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class FunctionInvocationKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FUNCTION_INVOCATION_KIND_UNSPECIFIED: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_SYSTEM: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_EXTENSION: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_USER: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_LAMBDA: _ClassVar[FunctionInvocationKind]
FUNCTION_INVOCATION_KIND_UNSPECIFIED: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_SYSTEM: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_EXTENSION: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_USER: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_LAMBDA: FunctionInvocationKind



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/diagnostic.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/diagnostic.proto\x12\x18ares.datamodel.scripting"\xbb\x01\n\nDiagnostic\x12\x12\n\nstart_line\x18\x01 \x01(\x05\x12\x14\n\x0cstart_column\x18\x02 \x01(\x05\x12\x10\n\x08end_line\x18\x03 \x01(\x05\x12\x12\n\nend_column\x18\x04 \x01(\x05\x12\x0f\n\x07message\x18\x05 \x01(\t\x12>\n\x08severity\x18\x06 \x01(\x0e2,.ares.datamodel.scripting.DiagnosticSeverity\x12\x0c\n\x04code\x18\x07 \x01(\t*\x90\x01\n\x12DiagnosticSeverity\x12\x1d\n\x19DIAGNOSTIC_SEVERITY_ERROR\x10\x00\x12\x1f\n\x1bDIAGNOSTIC_SEVERITY_WARNING\x10\x01\x12\x1c\n\x18DIAGNOSTIC_SEVERITY_INFO\x10\x02\x12\x1c\n\x18DIAGNOSTIC_SEVERITY_HINT\x10\x03b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.diagnostic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DIAGNOSTICSEVERITY']._serialized_start = 247
    _globals['_DIAGNOSTICSEVERITY']._serialized_end = 391
    _globals['_DIAGNOSTIC']._serialized_start = 57
    _globals['_DIAGNOSTIC']._serialized_end = 244


import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceState(_message.Message):
    __slots__ = ("device_id", "timestamp", "data")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    timestamp: _timestamp_pb2.Timestamp
    data: _ares_struct_pb2.AresStruct
    def __init__(self, device_id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., data: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...



"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_safety_service_pb2 as ares__safety__service__pb2
GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_safety_service_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresSafetyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RequestEmergencyStop = channel.unary_unary('/ares.services.AresSafetyService/RequestEmergencyStop', request_serializer=ares__safety__service__pb2.EmergencyStopRequest.SerializeToString, response_deserializer=ares__safety__service__pb2.EmergencyStopResponse.FromString, _registered_method=True)

class AresSafetyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RequestEmergencyStop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresSafetyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'RequestEmergencyStop': grpc.unary_unary_rpc_method_handler(servicer.RequestEmergencyStop, request_deserializer=ares__safety__service__pb2.EmergencyStopRequest.FromString, response_serializer=ares__safety__service__pb2.EmergencyStopResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.AresSafetyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.AresSafetyService', rpc_method_handlers)

class AresSafetyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RequestEmergencyStop(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresSafetyService/RequestEmergencyStop', ares__safety__service__pb2.EmergencyStopRequest.SerializeToString, ares__safety__service__pb2.EmergencyStopResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


from templates import parameter_metadata_pb2 as _parameter_metadata_pb2
from templates import variable_allocation_pb2 as _variable_allocation_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Parameter(_message.Message):
    __slots__ = ("unique_id", "metadata", "value", "planned", "environment_based", "planning_metadata", "variable_type", "variable_argument", "index")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    PLANNED_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_BASED_FIELD_NUMBER: _ClassVar[int]
    PLANNING_METADATA_FIELD_NUMBER: _ClassVar[int]
    VARIABLE_TYPE_FIELD_NUMBER: _ClassVar[int]
    VARIABLE_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    metadata: _parameter_metadata_pb2.ParameterMetadata
    value: _ares_struct_pb2.AresValue
    planned: bool
    environment_based: bool
    planning_metadata: _parameter_metadata_pb2.ParameterMetadata
    variable_type: _variable_allocation_pb2.VariableType
    variable_argument: str
    index: int
    def __init__(self, unique_id: _Optional[str] = ..., metadata: _Optional[_Union[_parameter_metadata_pb2.ParameterMetadata, _Mapping]] = ..., value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ..., planned: bool = ..., environment_based: bool = ..., planning_metadata: _Optional[_Union[_parameter_metadata_pb2.ParameterMetadata, _Mapping]] = ..., variable_type: _Optional[_Union[_variable_allocation_pb2.VariableType, str]] = ..., variable_argument: _Optional[str] = ..., index: _Optional[int] = ...) -> None: ...



import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ManualPlannerSeed(_message.Message):
    __slots__ = ("planner_values", "file_lines")
    PLANNER_VALUES_FIELD_NUMBER: _ClassVar[int]
    FILE_LINES_FIELD_NUMBER: _ClassVar[int]
    planner_values: ManualPlannerSetCollection
    file_lines: ManualPlannerFileLines
    def __init__(self, planner_values: _Optional[_Union[ManualPlannerSetCollection, _Mapping]] = ..., file_lines: _Optional[_Union[ManualPlannerFileLines, _Mapping]] = ...) -> None: ...

class ManualPlannerSet(_message.Message):
    __slots__ = ("parameter_values",)
    PARAMETER_VALUES_FIELD_NUMBER: _ClassVar[int]
    parameter_values: _containers.RepeatedCompositeFieldContainer[ParameterNameValuePair]
    def __init__(self, parameter_values: _Optional[_Iterable[_Union[ParameterNameValuePair, _Mapping]]] = ...) -> None: ...

class ParameterNameValuePair(_message.Message):
    __slots__ = ("name", "value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: _ares_struct_pb2.AresValue
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ...) -> None: ...

class ManualPlannerFileLines(_message.Message):
    __slots__ = ("planner_values",)
    PLANNER_VALUES_FIELD_NUMBER: _ClassVar[int]
    planner_values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, planner_values: _Optional[_Iterable[str]] = ...) -> None: ...

class ManualPlannerSetCollection(_message.Message):
    __slots__ = ("planned_values",)
    PLANNED_VALUES_FIELD_NUMBER: _ClassVar[int]
    planned_values: _containers.RepeatedCompositeFieldContainer[ManualPlannerSet]
    def __init__(self, planned_values: _Optional[_Iterable[_Union[ManualPlannerSet, _Mapping]]] = ...) -> None: ...
